@@ -122,7 +122,7 @@ class Ui_MainWindow(QWidget):
         	self.combo.addItem(Game)
 
         self.startButton = QPushButton("Start",self)
-        self.startButton.setGeometry(QRect(0, 370, 200, 55))
+        self.startButton.setGeometry(QRect(0, 370, 150, 55))
         font = QFont()
         font.setPointSize(24)
         self.startButton.setFont(font)
@@ -130,8 +130,17 @@ class Ui_MainWindow(QWidget):
 		, SIGNAL("clicked()")
 		, self.on_start_clicked)
 
+        self.exitCheckBox = QCheckBox("Exit gui",self)
+        self.exitCheckBox.setGeometry(QRect(150, 370, 190, 55))
+        font = QFont()
+        font.setPointSize(24)
+        self.exitCheckBox.setFont(font)
+	if self.gui_opts["exit_after_launch"] == "false":
+            self.exitCheckBox.setChecked(False)
+	else:
+            self.exitCheckBox.setChecked(True)
         self.muteCheckBox = QCheckBox("Mute",self)
-        self.muteCheckBox.setGeometry(QRect(200, 370, 200, 55))
+        self.muteCheckBox.setGeometry(QRect(340, 370, 170, 55))
         font = QFont()
         font.setPointSize(24)
         self.muteCheckBox.setFont(font)
@@ -141,7 +150,7 @@ class Ui_MainWindow(QWidget):
             self.muteCheckBox.setChecked(True)
 
         self.configButton = QPushButton("Config",self)
-        self.configButton.setGeometry(QRect(400, 370, 200, 55))
+        self.configButton.setGeometry(QRect(510, 370, 150, 55))
         font = QFont()
         font.setPointSize(24)
         self.configButton.setFont(font)
@@ -150,7 +159,7 @@ class Ui_MainWindow(QWidget):
 		, self.slotConfig)
 
         self.pushAboutButton = QPushButton("About",self)
-        self.pushAboutButton.setGeometry(QRect(600, 370, 200, 55))
+        self.pushAboutButton.setGeometry(QRect(660, 370, 140, 55))
         self.pushAboutButton.setFont(font)
 	QObject.connect(self.pushAboutButton
 		, SIGNAL("clicked()")
@@ -201,11 +210,35 @@ class Ui_MainWindow(QWidget):
 				# Keep the app responsive in this loop
 				QCoreApplication.processEvents()
 			#print >> sys.stderr,line
-		    if (self.MyTeller > 90) or ("Convert" in line):
+		    if (self.MyTeller > 90) or (self.MyTeller == 0) or ("Convert" in line):
 			file.close()
 			open(GNGEOGUI_LOG_FILE, 'w').close()
 			break
 
+        if (self.exitCheckBox.isChecked()) and (self.gui_opts["exit_after_launch"] == "false"):
+		try:
+			ConfigFile = open(GNGEOGUI_CFG_FILE,"w")
+		except:
+			QMessageBox.critical(self, "Warning",  "Cannot write " + GNGEOGUI_CFG_FILE)
+		else:
+			ConfigFile.write("# Generated by gngeo-gui\n")
+			ConfigFile.write("exec_path" + " " + self.gui_opts["exec_path"] + "\n")
+			ConfigFile.write("exit_after_launch" + " " + "true\n")
+			ConfigFile.close()
+
+        if (not self.exitCheckBox.isChecked()) and (self.gui_opts["exit_after_launch"] == "true"):
+		try:
+			ConfigFile = open(GNGEOGUI_CFG_FILE,"w")
+		except:
+			QMessageBox.critical(self, "Warning",  "Cannot write " + GNGEOGUI_CFG_FILE)
+		else:
+			ConfigFile.write("# Generated by gngeo-gui\n")
+			ConfigFile.write("exec_path" + " " + self.gui_opts["exec_path"] + "\n")
+			ConfigFile.write("exit_after_launch" + " " + "false\n")
+			ConfigFile.close()
+
+        if self.exitCheckBox.isChecked():
+               os._exit(0)
 
     def slotAbout(self):
         a = AboutWindow(self)
@@ -239,6 +272,7 @@ class ConfigWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.options = parse_config(self,GNGEO_CFG_FILE)
+        self.gui_opts = parse_config(self,GNGEOGUI_CFG_FILE)
         font = QFont()
         font.setPointSize(20)
 	#showfps
@@ -396,6 +430,7 @@ class ConfigWindow(QMainWindow):
 		else:
 			ConfigFile.write("# Generated by gngeo-gui\n")
 			ConfigFile.write("exec_path" + " " + ExecPath + "\n")
+			ConfigFile.write("exit_after_launch" + " " + self.gui_opts["exit_after_launch"] + "\n")
 			ConfigFile.close()
 
 	if P1buttons != "":
